@@ -2,11 +2,13 @@ from . import config
 from .config import options
 
 from . import estat
+from . import estatFile
 
 from .version import __version__
 
 
 __all__ = [
     "config", "options",
-    "estat",
+    "estat", "estatFile",
+    "__version__"
 ]
